@@ -4,7 +4,15 @@ ci_kenward <- function(model, ci = .95) {
   .check_REML_fit(model)
   df_kr <- dof_kenward(model)
   out <- lapply(ci, function(i) {
-    .ci_wald(model = model, ci = i, dof = df_kr, effects = "fixed", component = "all", method = "kenward", se = attr(df_kr, "se", exact = TRUE))
+    .ci_wald(
+      model = model,
+      ci = i,
+      dof = df_kr,
+      effects = "fixed",
+      component = "all",
+      method = "kenward",
+      se = attr(df_kr, "se", exact = TRUE)
+    )
   })
   out <- do.call(rbind, out)
   row.names(out) <- NULL
@@ -15,7 +23,15 @@ ci_kenward <- function(model, ci = .95) {
 
 .ci_kenward_dof <- function(model, ci = .95, df_kr) {
   out <- lapply(ci, function(i) {
-    .ci_wald(model = model, ci = i, dof = df_kr$df_error, effects = "fixed", component = "all", method = "kenward", se = df_kr$SE)
+    .ci_wald(
+      model = model,
+      ci = i,
+      dof = df_kr$df_error,
+      effects = "fixed",
+      component = "all",
+      method = "kenward",
+      se = df_kr$SE
+    )
   })
   out <- do.call(rbind, out)
   row.names(out) <- NULL
