@@ -1,8 +1,8 @@
 # generic function ------------------------------------------------------
 
 
-#' @importFrom insight get_statistic get_parameters get_sigma
-#' @importFrom stats confint p.adjust.methods p.adjust
+#' @importFrom insight get_statistic get_parameters
+#' @importFrom stats confint
 #' @keywords internal
 .extract_parameters_generic <- function(model,
                                         ci,
@@ -15,6 +15,7 @@
                                         p_adjust = NULL,
                                         wb_component = FALSE,
                                         verbose = TRUE,
+                                        keep_component_column = FALSE,
                                         ...) {
 
   # ==== check if standardization is required and package available
@@ -103,9 +104,9 @@
       ))
     }
     if (!is.null(ci_df)) {
-      if (length(ci) > 1) ci_df <- bayestestR::reshape_ci(ci_df)
+      if (length(ci) > 1) ci_df <- insight::reshape_ci(ci_df)
       ci_cols <- names(ci_df)[!names(ci_df) %in% c("CI", merge_by)]
-      parameters <- merge(parameters, ci_df, by = merge_by)
+      parameters <- merge(parameters, ci_df, by = merge_by, sort = FALSE)
     } else {
       ci_cols <- c()
     }
@@ -135,7 +136,7 @@
   }
 
   if (!is.null(pval)) {
-    parameters <- merge(parameters, pval, by = merge_by)
+    parameters <- merge(parameters, pval, by = merge_by, sort = FALSE)
   }
 
 
@@ -162,7 +163,7 @@
   }
 
   if (!is.null(std_err)) {
-    parameters <- merge(parameters, std_err, by = merge_by)
+    parameters <- merge(parameters, std_err, by = merge_by, sort = FALSE)
   }
 
 
@@ -171,7 +172,7 @@
   if (isTRUE(robust)) {
     parameters$Statistic <- parameters$Estimate / parameters$SE
   } else if (!is.null(statistic)) {
-    parameters <- merge(parameters, statistic, by = merge_by)
+    parameters <- merge(parameters, statistic, by = merge_by, sort = FALSE)
   }
 
 
@@ -182,7 +183,13 @@
     df_error <- degrees_of_freedom(model, method = "any")
   }
   if (!is.null(df_error) && (length(df_error) == 1 || length(df_error) == nrow(parameters))) {
-    parameters$df_error <- df_error
+    if (length(df_error) == 1) {
+      parameters$df_error <- df_error
+    } else {
+      # order may have changed due to merging, so make sure
+      # df are in correct order.
+      parameters$df_error <- df_error[order(parameters$.id)]
+    }
   }
 
 
@@ -218,14 +225,14 @@
 
   # ==== remove Component column if not needed
 
-  if (!is.null(parameters$Component) && .n_unique(parameters$Component) == 1) parameters$Component <- NULL
+  if (!is.null(parameters$Component) && .n_unique(parameters$Component) == 1 && !keep_component_column) parameters$Component <- NULL
   if ((!is.null(parameters$Effects) && .n_unique(parameters$Effects) == 1) || effects == "fixed") parameters$Effects <- NULL
 
 
   # ==== adjust p-values?
 
-  if (!is.null(p_adjust) && tolower(p_adjust) %in% stats::p.adjust.methods && "p" %in% colnames(parameters)) {
-    parameters$p <- stats::p.adjust(parameters$p, method = p_adjust)
+  if (!is.null(p_adjust)) {
+    parameters <- .p_adjust(parameters, p_adjust, model, verbose)
   }
 
 
@@ -274,9 +281,22 @@
   parameters <- parameters[col_order[col_order %in% names(parameters)]]
 
 
-  # ==== add sigma
+  # ==== add sigma and residual df
 
-  if (is.null(parameters$Component) || !"sigma" %in% parameters$Component) {
+  parameters <- .add_sigma_residual_df(parameters, model)
+
+
+  rownames(parameters) <- NULL
+  parameters
+}
+
+
+# helper ----------------
+
+
+#' @importFrom insight get_sigma get_df
+.add_sigma_residual_df <- function(params, model) {
+  if (is.null(params$Component) || !"sigma" %in% params$Component) {
     sig <- tryCatch(
       {
         suppressWarnings(insight::get_sigma(model))
@@ -285,12 +305,19 @@
         NULL
       }
     )
-    attr(parameters, "sigma") <- as.numeric(sig)
+    attr(params, "sigma") <- as.numeric(sig)
+
+    resdf <- tryCatch(
+      {
+        suppressWarnings(insight::get_df(model, type = "residual"))
+      },
+      error = function(e) {
+        NULL
+      }
+    )
+    attr(params, "residual_df") <- as.numeric(resdf)
   }
-
-
-  rownames(parameters) <- NULL
-  parameters
+  params
 }
 
 
@@ -308,10 +335,13 @@
                                       robust = FALSE,
                                       p_adjust = NULL,
                                       wb_component = FALSE,
+                                      verbose = TRUE,
                                       ...) {
   # check if standardization is required and package available
   if (!is.null(standardize) && !requireNamespace("effectsize", quietly = TRUE)) {
-    insight::print_color("Package 'effectsize' required to calculate standardized coefficients. Please install it.\n", "red")
+    if (verbose) {
+      warning("Package 'effectsize' required to calculate standardized coefficients. Please install it.", call. = FALSE)
+    }
     standardize <- NULL
   }
 
@@ -371,9 +401,9 @@
     } else {
       ci_df <- ci(model, ci = ci, method = df_method, effects = "fixed")
     }
-    if (length(ci) > 1) ci_df <- bayestestR::reshape_ci(ci_df)
+    if (length(ci) > 1) ci_df <- insight::reshape_ci(ci_df)
     ci_cols <- names(ci_df)[!names(ci_df) %in% c("CI", "Parameter")]
-    parameters <- merge(parameters, ci_df, by = "Parameter")
+    parameters <- merge(parameters, ci_df, by = "Parameter", sort = FALSE)
   } else {
     ci_cols <- c()
   }
@@ -382,30 +412,30 @@
   # standard error - only if we don't already have SE for std. parameters
   if (!("SE" %in% colnames(parameters))) {
     if (isTRUE(robust)) {
-      parameters <- merge(parameters, standard_error_robust(model, ...), by = "Parameter")
+      parameters <- merge(parameters, standard_error_robust(model, ...), by = "Parameter", sort = FALSE)
       # special handling for KR-SEs, which we already have computed from dof
     } else if ("SE" %in% colnames(df_error)) {
       se_kr <- df_error
       se_kr$df_error <- NULL
-      parameters <- merge(parameters, se_kr, by = "Parameter")
+      parameters <- merge(parameters, se_kr, by = "Parameter", sort = FALSE)
     } else {
-      parameters <- merge(parameters, standard_error(model, method = df_method, effects = "fixed"), by = "Parameter")
+      parameters <- merge(parameters, standard_error(model, method = df_method, effects = "fixed"), by = "Parameter", sort = FALSE)
     }
   }
 
 
   # p value
   if (isTRUE(robust)) {
-    parameters <- merge(parameters, p_value_robust(model, ...), by = "Parameter")
+    parameters <- merge(parameters, p_value_robust(model, ...), by = "Parameter", sort = FALSE)
   } else {
     if ("Pr(>|z|)" %in% names(parameters)) {
       names(parameters)[grepl("Pr(>|z|)", names(parameters), fixed = TRUE)] <- "p"
     } else if (df_method %in% special_df_methods) {
       # special handling for KR-p, which we already have computed from dof
       # parameters <- merge(parameters, .p_value_dof_kr(model, params = parameters, dof = df_error), by = "Parameter")
-      parameters <- merge(parameters, .p_value_dof(model, dof = df_error$df_error, method = df_method, se = df_error$SE), by = "Parameter")
+      parameters <- merge(parameters, .p_value_dof(model, dof = df_error$df_error, method = df_method, se = df_error$SE), by = "Parameter", sort = FALSE)
     } else {
-      parameters <- merge(parameters, p_value(model, dof = df, effects = "fixed"), by = "Parameter")
+      parameters <- merge(parameters, p_value(model, dof = df, effects = "fixed"), by = "Parameter", sort = FALSE)
     }
   }
 
@@ -414,7 +444,7 @@
   if (isFALSE(robust) && df_method %in% special_df_methods) {
     parameters$Statistic <- parameters$Estimate / parameters$SE
   } else {
-    parameters <- merge(parameters, statistic, by = "Parameter")
+    parameters <- merge(parameters, statistic, by = "Parameter", sort = FALSE)
   }
 
 
@@ -431,7 +461,7 @@
       if ("SE" %in% colnames(df_error)) {
         df_error$SE <- NULL
       }
-      parameters <- merge(parameters, df_error, by = "Parameter")
+      parameters <- merge(parameters, df_error, by = "Parameter", sort = FALSE)
     }
   }
 
@@ -447,8 +477,8 @@
   names(parameters) <- gsub("z value", "z", names(parameters))
 
   # adjust p-values?
-  if (!is.null(p_adjust) && tolower(p_adjust) %in% stats::p.adjust.methods && "p" %in% colnames(parameters)) {
-    parameters$p <- stats::p.adjust(parameters$p, method = p_adjust)
+  if (!is.null(p_adjust)) {
+    parameters <- .p_adjust(parameters, p_adjust, model, verbose)
   }
 
   # if we have within/between effects (from demean()), we can add a component
@@ -483,18 +513,7 @@
 
 
   # add sigma
-  if (is.null(parameters$Component) || !"sigma" %in% parameters$Component) {
-    sig <- tryCatch(
-      {
-        suppressWarnings(insight::get_sigma(model))
-      },
-      error = function(e) {
-        NULL
-      }
-    )
-    attr(parameters, "sigma") <- as.numeric(sig)
-  }
-
+  parameters <- .add_sigma_residual_df(parameters, model)
 
   rownames(parameters) <- NULL
   parameters
@@ -569,8 +588,8 @@
 # Bayes function ------------------------------------------------------
 
 
-#' @importFrom bayestestR describe_posterior reshape_ci
-#' @importFrom insight is_multivariate
+#' @importFrom bayestestR describe_posterior
+#' @importFrom insight is_multivariate reshape_ci
 #' @importFrom stats sd setNames na.omit
 #' @keywords internal
 .extract_parameters_bayesian <- function(model,
@@ -583,8 +602,9 @@
                                          rope_ci = 1.0,
                                          bf_prior = NULL,
                                          diagnostic = c("ESS", "Rhat"),
-                                         priors = TRUE,
+                                         priors = FALSE,
                                          standardize = NULL,
+                                         verbose = TRUE,
                                          ...) {
   # check if standardization is required and package available
   if (!is.null(standardize) && !requireNamespace("effectsize", quietly = TRUE)) {
@@ -610,6 +630,7 @@
       rope_range = rope_range,
       rope_ci = rope_ci,
       diagnostic = "ESS",
+      verbose = verbose,
       ...
     )
   } else if (!is.null(standardize)) {
@@ -625,6 +646,7 @@
       bf_prior = bf_prior,
       diagnostic = diagnostic,
       priors = priors,
+      verbose = verbose,
       ...
     )
 
@@ -641,6 +663,7 @@
       test = test_no_BF,
       rope_range = rope_range,
       rope_ci = rope_ci,
+      verbose = verbose,
       ...
     )
 
@@ -658,12 +681,13 @@
       bf_prior = bf_prior,
       diagnostic = diagnostic,
       priors = priors,
+      verbose = verbose,
       ...
     )
   }
 
   if (length(ci) > 1) {
-    parameters <- bayestestR::reshape_ci(parameters)
+    parameters <- insight::reshape_ci(parameters)
   }
 
   # Remove unnecessary columns
@@ -678,6 +702,7 @@
     parameters$ROPE_high <- NULL
   }
 
+  rownames(parameters) <- NULL
   parameters
 }
 
@@ -689,15 +714,22 @@
 
 
 #' @keywords internal
-.extract_parameters_lavaan <- function(model, ci = 0.95, standardize = FALSE, ...) {
+.extract_parameters_lavaan <- function(model, ci = 0.95, standardize = FALSE, verbose = TRUE, ...) {
   if (!requireNamespace("lavaan", quietly = TRUE)) {
     stop("Package 'lavaan' required for this function to work. Please install it by running `install.packages('lavaan')`.")
   }
 
+  # set proper default
+  if (is.null(standardize)) {
+    standardize <- FALSE
+  }
+
   # check for valid parameters
   if (!is.logical(standardize)) {
     if (!(standardize %in% c("all", "std.all", "latent", "std.lv", "no_exogenous", "std.nox"))) {
-      warning("'standardize' should be one of TRUE, 'all', 'std.all', 'latent', 'std.lv', 'no_exogenous' or 'std.nox'. Returning unstandardized solution.", call. = FALSE)
+      if (verbose) {
+        warning("'standardize' should be one of TRUE, 'all', 'std.all', 'latent', 'std.lv', 'no_exogenous' or 'std.nox'. Returning unstandardized solution.", call. = FALSE)
+      }
       standardize <- FALSE
     }
   }
@@ -705,7 +737,9 @@
   # CI
   if (length(ci) > 1) {
     ci <- ci[1]
-    warning(paste0("lavaan models only accept one level of CI :( Keeping the first one: `ci = ", ci, "`."))
+    if (verbose) {
+      warning(paste0("lavaan models only accept one level of CI :( Keeping the first one: `ci = ", ci, "`."), call. = FALSE)
+    }
   }
 
   # collect dots
@@ -744,8 +778,7 @@
     if (is.logical(standardize)) {
       standardize <- "all"
     }
-    type <- switch(
-      standardize,
+    type <- switch(standardize,
       "all" = ,
       "std.all" = "std.all",
       "latent" = ,
@@ -759,36 +792,24 @@
   }
 
 
-  if (inherits(model, "blavaan")) {
-    params <- data.frame(
-      To = data$lhs,
-      Operator = data$op,
-      From = data$rhs,
-      Coefficient = data$est,
-      SE = data$se,
-      CI_low = data$ci.lower,
-      CI_high = data$ci.upper,
-      stringsAsFactors = FALSE
-    )
-  } else {
-    params <- data.frame(
-      To = data$lhs,
-      Operator = data$op,
-      From = data$rhs,
-      Coefficient = data$est,
-      SE = data$se,
-      CI_low = data$ci.lower,
-      CI_high = data$ci.upper,
-      p = data$pvalue,
-      stringsAsFactors = FALSE
-    )
-  }
+  params <- data.frame(
+    To = data$lhs,
+    Operator = data$op,
+    From = data$rhs,
+    Coefficient = data$est,
+    SE = data$se,
+    CI_low = data$ci.lower,
+    CI_high = data$ci.upper,
+    z = data$z,
+    p = data$pvalue,
+    stringsAsFactors = FALSE
+  )
 
   if (!is.null(label)) {
     params$Label <- label
   }
 
-  params$Type <- ifelse(params$Operator == "=~", "Loading",
+  params$Component <- ifelse(params$Operator == "=~", "Loading",
     ifelse(params$Operator == "~", "Regression",
       ifelse(params$Operator == "~~", "Correlation",
         ifelse(params$Operator == ":=", "Defined",
@@ -797,7 +818,7 @@
       )
     )
   )
-  params$Type <- ifelse(as.character(params$From) == as.character(params$To), "Variance", params$Type)
+  params$Component <- ifelse(as.character(params$From) == as.character(params$To), "Variance", params$Component)
 
   if ("p" %in% colnames(params)) {
     params$p <- ifelse(is.na(params$p), 0, params$p)
