@@ -294,8 +294,7 @@ format_parameters.parameters_model <- function(model, ...) {
 
 #' @keywords internal
 .format_ordered <- function(degree, brackets = c("[", "]")) {
-  switch(
-    degree,
+  switch(degree,
     ".L" = paste0(brackets[1], "linear", brackets[2]),
     ".Q" = paste0(brackets[1], "quadratic", brackets[2]),
     ".C" = paste0(brackets[1], "cubic", brackets[2]),
