@@ -12,7 +12,7 @@ model_parameters.brmsfit <- function(model,
                                      rope_ci = 1.0,
                                      bf_prior = NULL,
                                      diagnostic = c("ESS", "Rhat"),
-                                     priors = TRUE,
+                                     priors = FALSE,
                                      effects = "fixed",
                                      component = "all",
                                      exponentiate = FALSE,
@@ -58,6 +58,7 @@ model_parameters.brmsfit <- function(model,
       effects = effects,
       component = component,
       standardize = standardize,
+      verbose = verbose,
       ...
     )
 
@@ -67,10 +68,19 @@ model_parameters.brmsfit <- function(model,
     }
 
     params <- .add_pretty_names(params, model)
+
     if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
       params <- .exponentiate_parameters(params, model, exponentiate)
     }
-    params <- .add_model_parameters_attributes(params, model, ci, exponentiate, ci_method = ci_method, verbose = verbose, ...)
+
+    params <- .add_model_parameters_attributes(params,
+      model,
+      ci,
+      exponentiate,
+      ci_method = ci_method,
+      verbose = verbose,
+      ...
+    )
 
     attr(params, "parameter_info") <- insight::clean_parameters(model)
     attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
@@ -93,7 +103,7 @@ model_parameters.brmsfit <- function(model,
                                         rope_range = "default",
                                         rope_ci = 1.0,
                                         diagnostic = c("ESS", "Rhat"),
-                                        priors = TRUE,
+                                        priors = FALSE,
                                         exponentiate = FALSE,
                                         standardize = NULL,
                                         verbose = TRUE,
@@ -106,44 +116,41 @@ model_parameters.brmsfit <- function(model,
   studies[] <- lapply(studies, function(i) i + smd[[1]])
   tau <- insight::get_parameters(model, effects = "random", parameters = "^sd_")
 
-  params <-
-    bayestestR::describe_posterior(
-      cbind(studies, smd),
-      centrality = centrality,
-      dispersion = dispersion,
-      ci = ci,
-      ci_method = ci_method,
-      test = test,
-      rope_range = rope_range,
-      rope_ci = rope_ci,
-      ...
-    )
+  params <- bayestestR::describe_posterior(
+    cbind(studies, smd),
+    centrality = centrality,
+    dispersion = dispersion,
+    ci = ci,
+    ci_method = ci_method,
+    test = test,
+    rope_range = rope_range,
+    rope_ci = rope_ci,
+    ...
+  )
 
-  params_diagnostics <-
-    bayestestR::diagnostic_posterior(
-      model,
-      effects = "all",
-      diagnostic = diagnostic,
-      ...
-    )
+  params_diagnostics <- bayestestR::diagnostic_posterior(
+    model,
+    effects = "all",
+    diagnostic = diagnostic,
+    ...
+  )
 
-  params_tau <-
-    bayestestR::describe_posterior(
-      tau,
-      centrality = centrality,
-      dispersion = dispersion,
-      ci = ci,
-      ci_method = ci_method,
-      test = test,
-      rope_range = rope_range,
-      rope_ci = rope_ci,
-      ...
-    )
+  params_tau <- bayestestR::describe_posterior(
+    tau,
+    centrality = centrality,
+    dispersion = dispersion,
+    ci = ci,
+    ci_method = ci_method,
+    test = test,
+    rope_range = rope_range,
+    rope_ci = rope_ci,
+    ...
+  )
 
   # add weights
   params$Weight <- 1 / c(insight::get_response(model)[[2]], NA)
 
-  # merge description with diagnostis
+  # merge description with diagnostic
   params <- merge(params, params_diagnostics, by = "Parameter", all.x = TRUE, sort = FALSE)
 
   # Renaming
@@ -176,7 +183,7 @@ model_parameters.brmsfit <- function(model,
   attr(params, "pretty_names") <- cleaned_parameters
   attr(params, "cleaned_parameters") <- cleaned_parameters
   attr(params, "ci") <- ci
-  attr(params, "bayes_ci_method") <- ci_method
+  attr(params, "ci_method") <- ci_method
   attr(params, "exponentiate") <- exponentiate
   attr(params, "model_class") <- class(model)
   attr(params, "is_bayes_meta") <- TRUE
