@@ -28,13 +28,14 @@
 #'
 #' @examples
 #' \donttest{
-#' if (require("lme4")) {
+#' if (require("lme4", quietly = TRUE)) {
 #'   model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
 #'   p_value_kenward(model)
 #' }
 #' }
 #' @return A data frame.
-#' @references Kenward, M. G., & Roger, J. H. (1997). Small sample inference for fixed effects from restricted maximum likelihood. Biometrics, 983-997.
+#' @references Kenward, M. G., & Roger, J. H. (1997). Small sample inference for
+#'   fixed effects from restricted maximum likelihood. Biometrics, 983-997.
 #' @importFrom stats pt coef
 #' @export
 p_value_kenward <- function(model, dof = NULL) {
@@ -56,20 +57,22 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
 
 # helper ------------------------------
 
-.p_value_dof <- function(model, dof, method, statistic = NULL) {
+.p_value_dof <- function(model, dof, method, statistic = NULL, se = NULL) {
   params <- insight::get_parameters(model)
   if (is.null(statistic)) {
     statistic <- insight::get_statistic(model)$Statistic
   }
 
   if (method == "kenward") {
-    se <- se_kenward(model)
+    if (is.null(se)) {
+      se <- se_kenward(model)$SE
+    }
     estimate <- if ("Coefficient" %in% colnames(params)) {
       params$Coefficient
     } else {
       params$Estimate
     }
-    statistic <- estimate / se$SE
+    statistic <- estimate / se
   }
 
   p <- 2 * stats::pt(abs(statistic), df = dof, lower.tail = FALSE)
