@@ -15,19 +15,22 @@
 #' @param show_sigma Logical, if \code{TRUE}, adds information about the residual
 #'   standard deviation.
 #' @param show_formula Logical, if \code{TRUE}, adds the model formula to the output.
-#' @inheritParams insight::parameters_table
+#' @param caption Table caption as string. If \code{NULL}, no table caption is printed.
+#' @param footer_digits Number of decimal places for values in the footer summary.
+#' @inheritParams insight::format_table
 #'
 #' @inheritSection format_parameters Interpretation of Interaction Terms
 #' @inheritSection model_parameters Labeling the Degrees of Freedom
 #'
 #' @return Invisibly returns the original input object.
 #'
-#' @seealso There is a dedicated method to use inside rmarkdown files, \code{\link[=print_md.parameters_model]{print_md()}}.
+#' @seealso There is a dedicated method to use inside rmarkdown files,
+#'   \code{\link[=print_md.parameters_model]{print_md()}}.
 #'
 #' @examples
 #' \donttest{
 #' library(parameters)
-#' if (require("glmmTMB")) {
+#' if (require("glmmTMB", quietly = TRUE)) {
 #'   model <- glmmTMB(
 #'     count ~ spp + mined + (1 | site),
 #'     ziformula = ~mined,
@@ -45,98 +48,75 @@
 #'   print(mp, select = "minimal")
 #' }
 #' }
-#'
-#' @importFrom insight export_table parameters_table
+#' @importFrom insight export_table
 #' @export
 print.parameters_model <- function(x,
                                    pretty_names = TRUE,
                                    split_components = TRUE,
                                    select = NULL,
+                                   caption = NULL,
                                    digits = 2,
                                    ci_digits = 2,
                                    p_digits = 3,
+                                   footer_digits = 3,
                                    show_sigma = FALSE,
                                    show_formula = FALSE,
+                                   zap_small = FALSE,
                                    ...) {
   # save original input
   orig_x <- x
 
-  # get attributes
-  res <- attributes(x)$details
-  sigma <- attributes(x)$sigma
-  p_adjust <- attributes(x)$p_adjust
-  model_formula <- attributes(x)$model_formula
-  ci_method <- .additional_arguments(x, "bayes_ci_method", NULL)
-  verbose <- .additional_arguments(x, "verbose", TRUE)
+  # table caption
+  table_caption <- .print_caption(x, caption, format = "text")
 
-  # set defaults, if necessary
-  if (is.null(sigma)) {
-    show_sigma <- FALSE
-  }
-
-  # check if user supplied digits attributes
-  if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
-  if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
-  if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
-
-
-  # print header
-  if (!is.null(attributes(x)$title)) {
-    insight::print_color(paste0("# ", attributes(x)$title, "\n\n"), "blue")
-  } else if (!is.null(res)) {
-    insight::print_color("# Fixed Effects\n\n", "blue")
-  }
-
-  formatted_table <- format(
-    x,
+  # main table
+  formatted_table <- .print_core(
+    x = x,
     pretty_names = pretty_names,
     split_components = split_components,
     select = select,
     digits = digits,
     ci_digits = ci_digits,
     p_digits = p_digits,
+    zap_small = zap_small,
     ci_width = "auto",
     ci_brackets = TRUE,
-    format = "text"
+    format = "text",
+    ...
   )
 
-  # prepare footer
-  footer <- NULL
+  # footer
+  footer <- .print_footer(
+    x,
+    digits = footer_digits,
+    show_sigma = show_sigma,
+    show_formula = show_formula
+  )
 
-  # footer: residual standard deviation
-  if (isTRUE(show_sigma)) {
-    footer <- .add_footer_sigma(footer, digits, sigma)
-  }
+  # get attributes
+  res <- attributes(x)$details
+  ci_method <- .additional_arguments(x, "ci_method", NULL)
+  verbose <- .additional_arguments(x, "verbose", TRUE)
 
-  # footer: p-adjustment
-  if ("p" %in% colnames(x) && isTRUE(verbose)) {
-    footer <- .add_footer_padjust(footer, p_adjust)
-  }
-
-  # footer: model formula
-  if (isTRUE(show_formula)) {
-    footer <- .add_footer_formula(footer, model_formula)
-  }
-
-  # add color code, if we have a footer
-  if (!is.null(footer)) {
-    footer <- c(footer, "blue")
-  }
-
-  cat(insight::export_table(formatted_table, format = "text", footer = footer))
+  # print main table
+  cat( insight::export_table(
+    formatted_table,
+    format = "text",
+    caption = table_caption,
+    footer = footer
+  ))
 
   # for Bayesian models
   if (isTRUE(verbose)) {
     .print_footer_cimethod(ci_method)
   }
 
+
+  ## TODO remove in future update when deprecated
+
   # print summary for random effects
   if (!is.null(res)) {
-    if (isTRUE(show_sigma)) {
-      cat("\n\n")
-    } else {
-      cat("\n")
-    }
+    cat("\n")
     .print_random_parameters(res, digits = digits)
   }
   invisible(orig_x)
@@ -151,6 +131,118 @@ print.parameters_brms_meta <- print.parameters_model
 
 
 
+# helper ------------------
+
+
+.print_core <- function(x,
+                        pretty_names = TRUE,
+                        split_components = TRUE,
+                        select = NULL,
+                        digits = 2,
+                        ci_digits = 2,
+                        p_digits = 3,
+                        zap_small = FALSE,
+                        ci_width = "auto",
+                        ci_brackets = TRUE,
+                        format = "text",
+                        ...) {
+  # check if user supplied digits attributes
+  digits <- .additional_arguments(x, "digits", digits)
+  ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+  p_digits <- .additional_arguments(x, "p_digits", p_digits)
+
+  format(
+    x,
+    pretty_names = pretty_names,
+    split_components = split_components,
+    select = select,
+    digits = digits,
+    ci_digits = ci_digits,
+    p_digits = p_digits,
+    ci_width = ci_width,
+    ci_brackets = ci_brackets,
+    zap_small = zap_small,
+    format = format,
+    ...
+  )
+}
+
+
+.print_footer <- function(x,
+                          digits = 3,
+                          show_sigma = FALSE,
+                          show_formula = FALSE,
+                          format = "text") {
+    # get attributes
+  sigma <- attributes(x)$sigma
+  verbose <- .additional_arguments(x, "verbose", TRUE)
+  digits <- .additional_arguments(x, "footer_digits", digits)
+
+  # override defaults. if argument "summary" is called in "model_parameters()",
+  # this overrides the defaults...
+  show_sigma <- .additional_arguments(x, "show_summary", show_sigma)
+  show_formula <- .additional_arguments(x, "show_summary", show_formula)
+  show_r2 <- .additional_arguments(x, "show_summary", FALSE)
+
+  # set defaults, if necessary
+  if (is.null(sigma)) {
+    show_sigma <- FALSE
+  }
+
+  .format_footer(
+    x,
+    digits = digits,
+    verbose = verbose,
+    show_sigma = show_sigma,
+    show_formula = show_formula,
+    show_r2 = show_r2,
+    format = format
+  )
+}
+
+
+
+.print_caption <- function(x, caption = NULL, format = "text") {
+  title_attribute <- attributes(x)$title
+
+  # check effects and component parts
+  if (!is.null(x$Effects) && all(x$Effects == "random")) {
+    eff_name <- "Random"
+  } else {
+    eff_name <- "Fixed"
+  }
+  if (!is.null(x$Component) && all(x$Component == "zero_inflated")) {
+    zero_inflated <- " (Zero-Inflated Model)"
+  } else {
+    zero_inflated <- ""
+  }
+
+  if (identical(format, "html") && is.null(caption)) {
+    table_caption <- "Model Summary"
+  } else if (isTRUE(attributes(x)$ordinal_model)) {
+    table_caption <- ""
+  } else if (!is.null(title_attribute) && is.null(caption)) {
+    if (title_attribute == "") {
+      table_caption <- NULL
+    } else {
+      table_caption <- title_attribute
+    }
+  } else if (!is.null(caption) && caption != "") {
+    table_caption <- caption
+  } else if (!is.null(caption) && caption == "") {
+    table_caption <- NULL
+  } else if (identical(format, "text")) {
+    table_caption <- c(paste0("# ", eff_name, " Effects", zero_inflated), "blue")
+  } else {
+    table_caption <- paste0(eff_name, " Effects", zero_inflated)
+  }
+
+  table_caption
+}
+
+
+
+
 
 # Random effects ------------------
 
@@ -175,7 +267,7 @@ print.parameters_stan <- function(x,
                                   p_digits = 3,
                                   ...) {
   orig_x <- x
-  ci_method <- .additional_arguments(x, "bayes_ci_method", NULL)
+  ci_method <- .additional_arguments(x, "ci_method", NULL)
   verbose <- .additional_arguments(x, "verbose", TRUE)
 
   # check if user supplied digits attributes
@@ -269,51 +361,3 @@ print.parameters_stan <- function(x,
     }
   }
 }
-
-
-
-
-
-# footer functions ------------------
-
-
-# footer: residual standard deviation
-.add_footer_sigma <- function(footer = NULL, digits, sigma) {
-  if (!is.null(sigma)) {
-    footer <- paste0(footer, sprintf("\nResidual standard deviation: %.*f", digits, sigma))
-  }
-  footer
-}
-
-
-# footer: p-adjustment
-.add_footer_padjust <- function(footer = NULL, p_adjust) {
-  if (!is.null(p_adjust) && p_adjust != "none") {
-    footer <- paste0(footer, "\np-value adjustment method: ", format_p_adjust(p_adjust))
-  }
-  footer
-}
-
-
-# footer: model formula
-.add_footer_formula <- function(footer = NULL, model_formula) {
-  if (!is.null(model_formula)) {
-    footer <- paste0(footer, "\nModel: ", model_formula)
-  }
-  footer
-}
-
-
-# footer: type of uncertainty interval
-.print_footer_cimethod <- function(ci_method = NULL) {
-  if (!is.null(ci_method)) {
-    ci_method <- switch(
-      toupper(ci_method),
-      "HDI" = "highest density intervals",
-      "ETI" = "equal-tailed intervals",
-      "SI" = "support intervals",
-      "uncertainty intervals"
-    )
-    message(paste0("\nUsing ", ci_method, " as credible intervals."))
-  }
-}
