@@ -13,26 +13,31 @@ print_html.parameters_model <- function(x,
                                         digits = 2,
                                         ci_digits = 2,
                                         p_digits = 3,
+                                        footer_digits = 3,
                                         ci_brackets = c("(", ")"),
                                         show_sigma = FALSE,
                                         show_formula = FALSE,
+                                        zap_small = FALSE,
                                         verbose = TRUE,
                                         ...) {
   # table caption
-  if (!is.null(attributes(x)$title) && is.null(caption)) {
-    table_caption <- attributes(x)$title
-  } else if (!is.null(caption)) {
-    table_caption <- caption
-  } else {
-    table_caption <- "Regression Model"
-  }
+  table_caption <- .print_caption(x, caption, format = "html")
 
-  # check if user supplied digits attributes
-  if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
-  if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
-  if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
-
-  formatted_table <- format(x, format = "html", pretty_names = pretty_names, split_components = split_components, select = select, digits = digits, ci_digits = ci_digits, p_digits = p_digits, ci_width = NULL, ci_brackets = ci_brackets)
+  # main table
+  formatted_table <- .print_core(
+    x = x,
+    pretty_names = pretty_names,
+    split_components = split_components,
+    select = select,
+    digits = digits,
+    ci_digits = ci_digits,
+    p_digits = p_digits,
+    zap_small = zap_small,
+    ci_width = NULL,
+    ci_brackets = ci_brackets,
+    format = "html",
+    ...
+  )
 
   # replace brackets by parenthesis
   if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
@@ -40,10 +45,24 @@ print_html.parameters_model <- function(x,
     formatted_table$Parameter <- gsub("]", ci_brackets[2], formatted_table$Parameter, fixed = TRUE)
   }
 
-  if (is.null(footer)) {
-    footer <- .format_footer(x, digits = digits, verbose = verbose, show_sigma = show_sigma, show_formula = show_formula, type = "html")
-  }
-  insight::export_table(formatted_table, format = "html", caption = table_caption, subtitle = subtitle, footer = footer, align = align, ...)
+  # footer
+  footer <- .print_footer(
+    x,
+    digits = footer_digits,
+    show_sigma = show_sigma,
+    show_formula = show_formula,
+    format = "html"
+  )
+
+  insight::export_table(
+    formatted_table,
+    format = "html",
+    caption = table_caption,
+    subtitle = subtitle,
+    footer = footer,
+    align = align,
+    ...
+  )
 }
 
 #' @export
@@ -63,7 +82,7 @@ print_html.compare_parameters <- function(x,
   orig_x <- x
 
   # get attributes
-  if (missing(style)) {
+  if (missing(style) || is.null(style)) {
     style <- attributes(x)$output_style
   }
 
