@@ -1,11 +1,18 @@
-#' Compute Skewness and Kurtosis
+#' Compute Skewness and (Excess) Kurtosis
 #'
 #' @param x A numeric vector or data.frame.
 #' @param na.rm Remove missing values.
-#' @param type Type of algorithm for computing skewness. May be one of \code{1} (or \code{"1"}, \code{"I"} or \code{"classic"}), \code{2} (or \code{"2"}, \code{"II"} or \code{"SPSS"} or \code{"SAS"}) or \code{3} (or  \code{"3"}, \code{"III"} or \code{"Minitab"}). See 'Details'.
-#' @param iterations The number of bootstrap replicates for computing standard errors. If \code{NULL} (default), parametric standard errors are computed. See 'Details'.
-#' @param test Logical, if \code{TRUE}, tests if skewness or kurtosis is significantly different from zero.
+#' @param type Type of algorithm for computing skewness. May be one of \code{1}
+#'   (or \code{"1"}, \code{"I"} or \code{"classic"}), \code{2} (or \code{"2"},
+#'   \code{"II"} or \code{"SPSS"} or \code{"SAS"}) or \code{3} (or  \code{"3"},
+#'   \code{"III"} or \code{"Minitab"}). See 'Details'.
+#' @param iterations The number of bootstrap replicates for computing standard
+#'   errors. If \code{NULL} (default), parametric standard errors are computed.
+#'   See 'Details'.
+#' @param test Logical, if \code{TRUE}, tests if skewness or kurtosis is
+#'   significantly different from zero.
 #' @param digits Number of decimal places.
+#' @param object An object returned by \code{skewness()} or \code{kurtosis()}.
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @details \subsection{Skewness}{
@@ -14,10 +21,12 @@
 #' positive skewness values indicates a "right-skewed" distribution. Examples
 #' for the relationship of skewness and distributions are:
 #' \itemize{
-#'   \item Normal distribution (and other symmetric distribution) has a skewness of 0
+#'   \item Normal distribution (and other symmetric distribution) has a skewness
+#'   of 0
 #'   \item Half-normal distribution has a skewness just below 1
 #'   \item Exponential distribution has a skewness of 2
-#'   \item Lognormal distribution can have a skewness of any positive value, depending on its parameters
+#'   \item Lognormal distribution can have a skewness of any positive value,
+#'   depending on its parameters
 #' }
 #' (\cite{https://en.wikipedia.org/wiki/Skewness})
 #' }
@@ -83,8 +92,7 @@ skewness.numeric <- function(x, na.rm = TRUE, type = "2", iterations = NULL, ...
     type <- "1"
   }
 
-  .skewness <- switch(
-    type,
+  .skewness <- switch(type,
     "1" = out,
     "2" = out * sqrt(n * (n - 1)) / (n - 2),
     "3" = out * ((1 - 1 / n))^1.5
@@ -92,8 +100,7 @@ skewness.numeric <- function(x, na.rm = TRUE, type = "2", iterations = NULL, ...
 
   out_se <- sqrt((6 * (n - 2)) / ((n + 1) * (n + 3)))
 
-  .skewness_se <- switch(
-    type,
+  .skewness_se <- switch(type,
     "1" = out_se,
     "2" = out_se * ((sqrt(n * (n - 1))) / (n - 2)),
     "3" = out_se * (((n - 1) / n)^1.5),
@@ -103,13 +110,21 @@ skewness.numeric <- function(x, na.rm = TRUE, type = "2", iterations = NULL, ...
     if (!requireNamespace("boot", quietly = TRUE)) {
       warning("Package 'boot' needed for bootstrapping SEs.", call. = FALSE)
     } else {
-      results <- boot::boot(data = x, statistic = .boot_skewness, R = iterations, na.rm = na.rm, type = type)
+      results <- boot::boot(
+        data = x,
+        statistic = .boot_skewness,
+        R = iterations,
+        na.rm = na.rm,
+        type = type
+      )
       out_se <- stats::sd(results$t, na.rm = TRUE)
     }
   }
 
-  .skewness <- data.frame(Skewness = .skewness,
-                          SE = out_se)
+  .skewness <- data.frame(
+    Skewness = .skewness,
+    SE = out_se
+  )
   class(.skewness) <- unique(c("parameters_skewness", class(.skewness)))
   .skewness
 }
@@ -176,33 +191,39 @@ kurtosis.numeric <- function(x, na.rm = TRUE, type = "2", iterations = NULL, ...
     type <- "1"
   }
 
-  .kurtosis <- switch(
-    type,
+  .kurtosis <- switch(type,
     "1" = out - 3,
-    "2" = ((n + 1) * (out - 3) + 6) * (n - 1)/((n - 2) * (n - 3)),
+    "2" = ((n + 1) * (out - 3) + 6) * (n - 1) / ((n - 2) * (n - 3)),
     "3" = out * (1 - 1 / n)^2 - 3
   )
 
   out_se <- sqrt((24 * n * (n - 2) * (n - 3)) / (((n + 1)^2) * (n + 3) * (n + 5)))
 
-  .kurtosis_se <- switch(
-    type,
+  .kurtosis_se <- switch(type,
     "1" = out_se,
     "2" = out_se * (((n - 1) * (n + 1)) / ((n - 2) * (n - 3))),
     "3" = out_se * ((n - 1) / n)^2
   )
 
-  if (!is.null(iterations )) {
+  if (!is.null(iterations)) {
     if (!requireNamespace("boot", quietly = TRUE)) {
       warning("Package 'boot' needed for bootstrapping SEs.", call. = FALSE)
     } else {
-      results <- boot::boot(data = x, statistic = .boot_kurtosis, R = iterations, na.rm = na.rm, type = type)
+      results <- boot::boot(
+        data = x,
+        statistic = .boot_kurtosis,
+        R = iterations,
+        na.rm = na.rm,
+        type = type
+      )
       out_se <- stats::sd(results$t, na.rm = TRUE)
     }
   }
 
-  .kurtosis <- data.frame(Kurtosis = .kurtosis,
-                          SE = out_se)
+  .kurtosis <- data.frame(
+    Kurtosis = .kurtosis,
+    SE = out_se
+  )
   class(.kurtosis) <- unique(c("parameters_kurtosis", class(.kurtosis)))
   .kurtosis
 }
@@ -263,17 +284,35 @@ as.double.parameters_skewness <- as.numeric.parameters_skewness
 #' @rdname skewness
 #' @export
 print.parameters_kurtosis <- function(x, digits = 3, test = FALSE, ...) {
-  .print_skew_kurt(x, val = "Kurtosis", digits = digits, test = test, ...)
+  out <- summary(x, test = test)
+  cat(insight::export_table(out, digits = digits))
   invisible(x)
 }
 
 #' @rdname skewness
 #' @export
-print.parameters_skewness <- function(x, digits = 3, test = FALSE, ...) {
-  .print_skew_kurt(x, val = "Skewness", digits = digits, test = test, ...)
-  invisible(x)
+print.parameters_skewness <- print.parameters_kurtosis
+
+#' @importFrom stats pnorm
+#' @rdname skewness
+#' @export
+summary.parameters_skewness <- function(object, test = FALSE, ...) {
+  if (test) {
+    object$z <- object$Skewness / object$SE
+    object$p <- 2 * (1 - stats::pnorm(abs(object$z)))
+  }
+  object
 }
 
+#' @rdname skewness
+#' @export
+summary.parameters_kurtosis <- function(object, test = FALSE, ...) {
+  if (test) {
+    object$z <- object$Kurtosis / object$SE
+    object$p <- 2 * (1 - stats::pnorm(abs(object$z)))
+  }
+  object
+}
 
 
 
@@ -291,8 +330,7 @@ print.parameters_skewness <- function(x, digits = 3, test = FALSE, ...) {
     type <- "2"
   }
 
-  switch(
-    type,
+  switch(type,
     "1" = ,
     "I" = ,
     "classic" = "1",
@@ -307,33 +345,22 @@ print.parameters_skewness <- function(x, digits = 3, test = FALSE, ...) {
 }
 
 
-.print_skew_kurt <- function(x, val, digits = 3, test = FALSE, ...) {
-  if (test) {
-    x$z <- x[[val]] / x$SE
-    x$p <- 2 * (1 - stats::pnorm(abs(x$z)))
-  }
-
-  attr(x, "digits") <- digits
-  out <- parameters_table(x)
-
-  cat(insight::format_table(out, digits = digits))
-}
-
-
 
 # bootstrapping -----------------------------------
 
 .boot_skewness <- function(data, indices, na.rm, type) {
   parameters::skewness(data[indices],
-                       na.rm = na.rm,
-                       type = type,
-                       iterations = NULL)$Skewness
+    na.rm = na.rm,
+    type = type,
+    iterations = NULL
+  )$Skewness
 }
 
 
 .boot_kurtosis <- function(data, indices, na.rm, type) {
   parameters::kurtosis(data[indices],
-                       na.rm = na.rm,
-                       type = type,
-                       iterations = NULL)$Kurtosis
+    na.rm = na.rm,
+    type = type,
+    iterations = NULL
+  )$Kurtosis
 }
