@@ -3,8 +3,8 @@ if (require("testthat") && require("parameters")) {
     data(mtcars)
     m <- lm(mpg ~ gear + wt + cyl + hp, data = mtcars)
     x <- equivalence_test(m)
-    testthat::expect_equal(c(nrow(x), ncol(x)), c(5, 8))
+    expect_equal(c(nrow(x), ncol(x)), c(5, 8))
 
-    testthat::expect_true(is.character(capture.output(equivalence_test(m))))
+    expect_true(is.character(capture.output(equivalence_test(m))))
   })
 }
