@@ -1,6 +1,4 @@
-if (require("testthat") &&
-  require("parameters") &&
-  require("geepack")) {
+if (require("testthat") && require("parameters") && require("geepack")) {
   data(warpbreaks)
   m1 <-
     geeglm(
